@@ -90,6 +90,7 @@ fd_set_size_t	   fd_width;
 window_list	   wins = NULL, wins_tail = NULL;
 int		   wins_count = 0;
 FILE		  *console;
+char		  *win_cmd = NULL;
 
 static void	   Loop(int *);
 static void	   process_message(unsigned long, unsigned long *);
@@ -129,6 +130,7 @@ int transients	 = 0;
 int maximized	 = 1;
 int titled	 = 1;
 int desk	 = 0;
+int on_screen	 = 0;
 int reversed	 = 0;
 int do_ewmhiwa	 = 0;
 int is_init	 = 1;
@@ -141,6 +143,7 @@ void
 free_resources(void)
 {
 	free_window_list(wins);
+	free(win_cmd);
 
 	if (console != stderr)
 		fclose(console);
@@ -343,9 +346,19 @@ is_suitable_window(unsigned long *body)
 		int y = (int)cfgpacket->frame_y;
 		int w = (int)cfgpacket->frame_width;
 		int h = (int)cfgpacket->frame_height;
-		if (x >= box_x + box_w || x + w <= box_x
-		    || y >= box_y + box_h || y + h <= box_y)
-			return 0;
+		if (on_screen) {
+			int mon_x = mon->si->x;
+			int mon_y = mon->si->y;
+			int mon_w = mon->si->w;
+			int mon_h = mon->si->h;
+			if (x >= mon_x + mon_w || x + w <= mon_x
+			   || y >= mon_y + mon_h || y + h <= mon_y)
+			   return 0;
+		} else {
+			if (x >= box_x + box_w || x + w <= box_x
+			   || y >= box_y + box_h || y + h <= box_y)
+			   return 0;
+		}
 	}
 
 	if (!transients && IS_TRANSIENT(cfgpacket))
@@ -442,6 +455,8 @@ move_resize_raise_window(window_item *wi, int x, int y, int w, int h)
 		SendText(fd, msg, wi->frame);
 	}
 
+	if (win_cmd)
+		SendText(fd, win_cmd, wi->frame);
 	if (raise_window)
 		SendText(fd, "Raise", wi->frame);
 }
@@ -729,6 +744,10 @@ parse_args(int argc, char *argv[], int argi)
 			do_animate = 1;
 		} else if (StrEquals(argv[argi], "-ewmhiwa")) {
 			do_ewmhiwa = 1;
+		} else if (StrEquals(argv[argi], "-win_cmd")
+			   && ((argi + 1) < argc)) {
+			free(win_cmd);
+			win_cmd = fxstrdup(argv[++argi]);
 
 		/* Resizing options */
 		} else if (StrEquals(argv[argi], "-noresize")) {
@@ -761,6 +780,8 @@ parse_args(int argc, char *argv[], int argi)
 			titled = 0;
 		} else if (StrEquals(argv[argi], "-desk")) {
 			desk = 1;
+		} else if (StrEquals(argv[argi], "-on_screen")) {
+			on_screen = 1;
 		} else if (StrEquals(argv[argi], "-ewmhiwa")) {
 			do_ewmhiwa = 1;
 
